# hypothesis-010

A [Hypothesis](https://hypothesis.readthedocs.io) strategy for generating data
that matches some [010 editor](https://www.sweetscape.com/010editor/)
binary template.

This includes over [170 binary file formats built in](https://www.sweetscape.com/010editor/repository/templates/),
and [many more from the community](https://www.google.com/search?q=github+010+templates).

[Here's the PyPI page](https://pypi.org/project/hypothesis-010/) and
[the GitHub repo](https://github.com/Zac-HD/hypothesis-010).

## API

`hypothesis-010` is in the planning stages, inspired by
[`FormatFuzzer`](https://uds-se.github.io/FormatFuzzer/) and the wide variety of
useful features already integrated into Hypothesis.

Check back soon to see what progress we've made, or [get in touch](mailto:zac@zhd.dev)
to let me know you're interested - this is a long way from the top of my todo list.


## Supported versions

`hypothesis-010` requires Python 3.6 or later.
In general, 0.x versions will require very recent versions of all dependencies
because I don't want to deal with compatibility workarounds.

You can [sponsor me](https://github.com/sponsors/Zac-HD) to get priority
support, roadmap input, and prioritized feature development.


## Changelog

Patch notes [can be found in `CHANGELOG.md`](https://github.com/Zac-HD/hypothesis-010/blob/master/CHANGELOG.md).
